========
CSV-like
========

.. image:: https://img.shields.io/github/license/mikesmitheu/csvlike.svg
    :target: https://github.com/MikeSmithEU/csvlike/blob/main/LICENCE.md

.. image:: https://img.shields.io/github/workflow/status/MikeSmithEU/csvlike/Python%20package
    :alt: GitHub Workflow Status (branch)
    :target: https://github.com/MikeSmithEU/csvlike/actions

.. image:: https://readthedocs.org/projects/csvlike/badge/?version=latest
    :target: https://csvlike.readthedocs.io/
    :alt: Documentation Status


Read CSV-like files with support of comments and trimming in native python.

